# DBotScore

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**content** | **str** |  | [optional] 
**content_format** | **str** |  | [optional] 
**context** | **dict(str, object)** |  | [optional] 
**is_typed_indicator** | **bool** |  | [optional] 
**score** | **int** |  | [optional] 
**score_change_timestamp** | **datetime** | We need to track when the score changes to know if we need to re-calculate the overall score | [optional] 
**timestamp** | **datetime** |  | [optional] 
**type** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


